==> ec2-1.15.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/AclCidr.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Either an IPv4 or an IPv6 CIDR.
 * 
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.19.0 (build 7c562bc)", date = "2019-10-28T12:23:13.943Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.AclCidr")
public abstract class AclCidr extends software.amazon.jsii.JsiiObject {

    protected AclCidr(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected AclCidr(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    protected AclCidr() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        this.setObjRef(software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this));
    }

    /**
     * The CIDR containing all IPv4 addresses (i.e., 0.0.0.0/0).
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static software.amazon.awscdk.services.ec2.AclCidr anyIpv4() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.AclCidr.class, "anyIpv4", software.amazon.awscdk.services.ec2.AclCidr.class);
    }

    /**
     * The CIDR containing all IPv6 addresses (i.e., ::/0).
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static software.amazon.awscdk.services.ec2.AclCidr anyIpv6() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.AclCidr.class, "anyIpv6", software.amazon.awscdk.services.ec2.AclCidr.class);
    }

    /**
     * An IP network range in CIDR notation (for example, 172.16.0.0/24).
     * 
     * EXPERIMENTAL
     * 
     * @param ipv4Cidr This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static software.amazon.awscdk.services.ec2.AclCidr ipv4(final java.lang.String ipv4Cidr) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.AclCidr.class, "ipv4", software.amazon.awscdk.services.ec2.AclCidr.class, new Object[] { java.util.Objects.requireNonNull(ipv4Cidr, "ipv4Cidr is required") });
    }

    /**
     * An IPv6 network range in CIDR notation (for example, 2001:db8::/48).
     * 
     * EXPERIMENTAL
     * 
     * @param ipv6Cidr This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static software.amazon.awscdk.services.ec2.AclCidr ipv6(final java.lang.String ipv6Cidr) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.AclCidr.class, "ipv6", software.amazon.awscdk.services.ec2.AclCidr.class, new Object[] { java.util.Objects.requireNonNull(ipv6Cidr, "ipv6Cidr is required") });
    }

    /**
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public abstract software.amazon.awscdk.services.ec2.AclCidrConfig toCidrConfig();

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.awscdk.services.ec2.AclCidr {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
        }

        /**
         * EXPERIMENTAL
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public software.amazon.awscdk.services.ec2.AclCidrConfig toCidrConfig() {
            return this.jsiiCall("toCidrConfig", software.amazon.awscdk.services.ec2.AclCidrConfig.class);
        }
    }
}

==> ec2-1.16.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/AclCidr.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Either an IPv4 or an IPv6 CIDR.
 * 
 * EXPERIMENTAL
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.20.2 (build faba0be)", date = "2019-11-11T17:17:50.711Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.AclCidr")
public abstract class AclCidr extends software.amazon.jsii.JsiiObject {

    protected AclCidr(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected AclCidr(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    protected AclCidr() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * The CIDR containing all IPv4 addresses (i.e., 0.0.0.0/0).
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static software.amazon.awscdk.services.ec2.AclCidr anyIpv4() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.AclCidr.class, "anyIpv4", software.amazon.awscdk.services.ec2.AclCidr.class);
    }

    /**
     * The CIDR containing all IPv6 addresses (i.e., ::/0).
     * 
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static software.amazon.awscdk.services.ec2.AclCidr anyIpv6() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.AclCidr.class, "anyIpv6", software.amazon.awscdk.services.ec2.AclCidr.class);
    }

    /**
     * An IP network range in CIDR notation (for example, 172.16.0.0/24).
     * 
     * EXPERIMENTAL
     * 
     * @param ipv4Cidr This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static software.amazon.awscdk.services.ec2.AclCidr ipv4(final java.lang.String ipv4Cidr) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.AclCidr.class, "ipv4", software.amazon.awscdk.services.ec2.AclCidr.class, new Object[] { java.util.Objects.requireNonNull(ipv4Cidr, "ipv4Cidr is required") });
    }

    /**
     * An IPv6 network range in CIDR notation (for example, 2001:db8::/48).
     * 
     * EXPERIMENTAL
     * 
     * @param ipv6Cidr This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static software.amazon.awscdk.services.ec2.AclCidr ipv6(final java.lang.String ipv6Cidr) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.AclCidr.class, "ipv6", software.amazon.awscdk.services.ec2.AclCidr.class, new Object[] { java.util.Objects.requireNonNull(ipv6Cidr, "ipv6Cidr is required") });
    }

    /**
     * EXPERIMENTAL
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public abstract software.amazon.awscdk.services.ec2.AclCidrConfig toCidrConfig();

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.awscdk.services.ec2.AclCidr {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * EXPERIMENTAL
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public software.amazon.awscdk.services.ec2.AclCidrConfig toCidrConfig() {
            return this.jsiiCall("toCidrConfig", software.amazon.awscdk.services.ec2.AclCidrConfig.class);
        }
    }
}
